Class: ScoutApm::Logging::Config::ConfigDefaults

Inherits:
Object
  • Object
show all
Defined in:
lib/scout_apm/logging/config.rb

Overview

Defaults in case no config file has been found.

Constant Summary collapse

DEFAULTS =
{
  'log_level' => 'info',
  'logs_capture_level' => 'debug',
  'logs_ingest_key' => '',
  'logs_reporting_endpoint' => 'https://otlp.scoutotel.com:4317',
  'logs_reporting_endpoint_http' => 'https://otlp.scoutotel.com:4318/v1/logs',
  'logs_proxy_log_dir' => '/tmp/scout_apm/logs/',
  'logs_log_file_size' => 1024 * 1024 * 10
}.freeze

Instance Method Summary collapse

Instance Method Details

#any_keys_found?Boolean

Dyanmic/computed values are here, but not counted as user specified.

Returns:

  • (Boolean)


132
133
134
# File 'lib/scout_apm/logging/config.rb', line 132

def any_keys_found?
  false
end

#has_key?(key) ⇒ Boolean

Returns:

  • (Boolean)


127
128
129
# File 'lib/scout_apm/logging/config.rb', line 127

def has_key?(key)
  DEFAULTS.key?(key)
end

#nameObject



136
137
138
# File 'lib/scout_apm/logging/config.rb', line 136

def name
  'defaults'
end

#value(key) ⇒ Object



123
124
125
# File 'lib/scout_apm/logging/config.rb', line 123

def value(key)
  DEFAULTS[key]
end